@@ -13,7 +13,7 @@ use std::{collections::HashMap, sync::Arc, time::Duration};
 /// let event = Arc::new(event);
 /// // The duration is the delay before the execution.
 /// event_processor.add_event(event, Duration::from_secs(5));
-/// event_processor.update(100);
+/// event_processor.update(1005000);
 ///
 /// struct MyEvent;
 ///
@@ -40,7 +40,7 @@ where
     /// ```rust, no_run
     /// use rollo::game::{EventProcessor, Event};
     ///
-    /// let event_processor = EventProcessor::<MyEvent>::new(10000);
+    /// let event_processor = EventProcessor::<MyEvent>::new(1000000);
     ///
     /// struct MyEvent;
     ///
@@ -77,7 +77,7 @@ where
 
         let mut keys_to_remove = HashMap::new();
 
-        for (time, events) in self.events.iter_all() {
+        for (time, events_i) in self.events.iter_all() {
             if *time > m_time {
                 continue;
             }
@@ -85,7 +85,7 @@ where
             keys_to_remove.insert(*time, Vec::new());
 
             if let Some(retain) = keys_to_remove.get_mut(&time.clone()) {
-                for event in events {
+                for event in events_i.iter() {
                     if event.1.to_abort() {
                         event.1.on_abort();
                     } else {
