@@ -1,11 +1,24 @@
+use crossbeam::atomic::AtomicCell;
+
 use super::{dos_protection::DosPolicy, world_session::WorldSession};
+use crate::game::GameTime;
+use async_trait::async_trait;
 
 /// Events for the World
-pub trait World: Sized + Sync + WorldTime + Send {
+#[async_trait]
+pub trait World: Sized + Sync + Send {
     type WorldSessionimplementer: WorldSession<Self> + 'static + Send + Sync;
 
-    /// Tick
-    fn update(&'static self, _diff: i64) {}
+    // Executed when server start.
+    async fn on_start(_game_time: &'static AtomicCell<GameTime>) {}
+
+    // Reference to a GameTime.
+    fn game_time(&'static self) -> Option<&'static AtomicCell<GameTime>> {
+        None
+    }
+
+    /// Update.
+    fn update(&'static self, _diff: i64, _game_time: GameTime) {}
 
     /// Packet limit.
     /// (amount, size, policy)
@@ -24,11 +37,3 @@ pub trait World: Sized + Sync + WorldTime + Send {
         (50, 5000)
     }
 }
-
-/// Current World Time
-pub trait WorldTime: Sized + Sync {
-    /// Current Time
-    fn time(&self) -> i64;
-    /// Update the time
-    fn update_time(&self, new_time: i64);
-}
